#ifndef NT2_INCLUDE_FUNCTIONS_ARECROSSCOMPATIBLE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ARECROSSCOMPATIBLE_HPP_INCLUDED

#include <nt2/predicates/include/functions/arecrosscompatible.hpp>

#endif
